==> qtjambi-dbus-debuginfo-macos-5.15.17.jar: sources/QtJambiDBus/metainfo.cpp <==
#include <QtJambi/MetaInfo>


void initialize_meta_info_QtDBus();
void initialize_meta_info_QDBus();
void initialize_meta_info_QDBusAbstractAdaptor();
void initialize_meta_info_QDBusAbstractInterface();
void initialize_meta_info_QDBusAbstractInterfaceBase();
void initialize_meta_info_QDBusArgument();
void initialize_meta_info_QDBusConnection();
void initialize_meta_info_QDBusConnectionInterface();
void initialize_meta_info_QDBusContext();
void initialize_meta_info_QDBusError();
void initialize_meta_info_QDBusInterface();
void initialize_meta_info_QDBusMessage();
void initialize_meta_info_QDBusObjectPath();
void initialize_meta_info_QDBusPendingCall();
void initialize_meta_info_QDBusPendingCallWatcher();
void initialize_meta_info_QDBusPendingReplyData();
void initialize_meta_info_QDBusServer();
void initialize_meta_info_QDBusServiceWatcher();
void initialize_meta_info_QDBusSignature();
void initialize_meta_info_QDBusUnixFileDescriptor();
void initialize_meta_info_QDBusVariant();
void initialize_meta_info_QDBusVirtualObject();

extern "C" Q_DECL_EXPORT jint JNICALL JNI_ONLOAD(JavaVM *, void *)
{
    QTJAMBI_LIBRARY_INITIALIZATION_METHOD_CALL("io.qt.dbus")

    initialize_meta_info_QtDBus();
    initialize_meta_info_QDBus();
    initialize_meta_info_QDBusAbstractAdaptor();
    initialize_meta_info_QDBusAbstractInterface();
    initialize_meta_info_QDBusAbstractInterfaceBase();
    initialize_meta_info_QDBusArgument();
    initialize_meta_info_QDBusConnection();
    initialize_meta_info_QDBusConnectionInterface();
    initialize_meta_info_QDBusContext();
    initialize_meta_info_QDBusError();
    initialize_meta_info_QDBusInterface();
    initialize_meta_info_QDBusMessage();
    initialize_meta_info_QDBusObjectPath();
    initialize_meta_info_QDBusPendingCall();
    initialize_meta_info_QDBusPendingCallWatcher();
    initialize_meta_info_QDBusPendingReplyData();
    initialize_meta_info_QDBusServer();
    initialize_meta_info_QDBusServiceWatcher();
    initialize_meta_info_QDBusSignature();
    initialize_meta_info_QDBusUnixFileDescriptor();
    initialize_meta_info_QDBusVariant();
    initialize_meta_info_QDBusVirtualObject();
    return QTJAMBI_ONLOAD_RETURN;
}

extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_dbus_QtJambi_1LibraryUtilities_internalAccess)(JNIEnv *env, jclass cls){
    jobject result{0};
    QTJAMBI_TRY{
        result = MetaInfoAPI::internalAccess(env, cls);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(env);
    }QTJAMBI_TRY_END
    return result;
}

==> qtjambi-dbus-debuginfo-macos-6.5.3.jar: sources/QtJambiDBus/metainfo.cpp <==
#include <QtJambi/MetaInfo>


void initialize_meta_info_QtDBus();
void initialize_meta_info_QDBus();
void initialize_meta_info_QDBusAbstractAdaptor();
void initialize_meta_info_QDBusAbstractInterface();
void initialize_meta_info_QDBusAbstractInterfaceBase();
void initialize_meta_info_QDBusArgument();
void initialize_meta_info_QDBusConnection();
void initialize_meta_info_QDBusConnectionInterface();
void initialize_meta_info_QDBusContext();
void initialize_meta_info_QDBusError();
void initialize_meta_info_QDBusInterface();
void initialize_meta_info_QDBusMessage();
void initialize_meta_info_QDBusObjectPath();
void initialize_meta_info_QDBusPendingCall();
void initialize_meta_info_QDBusPendingCallWatcher();
void initialize_meta_info_QDBusPendingReplyBase();
void initialize_meta_info_QDBusServer();
void initialize_meta_info_QDBusServiceWatcher();
void initialize_meta_info_QDBusSignature();
void initialize_meta_info_QDBusUnixFileDescriptor();
void initialize_meta_info_QDBusVariant();
void initialize_meta_info_QDBusVirtualObject();

extern "C" Q_DECL_EXPORT jint JNICALL JNI_ONLOAD(JavaVM *, void *)
{
    QTJAMBI_LIBRARY_INITIALIZATION_METHOD_CALL("io.qt.dbus")

    initialize_meta_info_QtDBus();
    initialize_meta_info_QDBus();
    initialize_meta_info_QDBusAbstractAdaptor();
    initialize_meta_info_QDBusAbstractInterface();
    initialize_meta_info_QDBusAbstractInterfaceBase();
    initialize_meta_info_QDBusArgument();
    initialize_meta_info_QDBusConnection();
    initialize_meta_info_QDBusConnectionInterface();
    initialize_meta_info_QDBusContext();
    initialize_meta_info_QDBusError();
    initialize_meta_info_QDBusInterface();
    initialize_meta_info_QDBusMessage();
    initialize_meta_info_QDBusObjectPath();
    initialize_meta_info_QDBusPendingCall();
    initialize_meta_info_QDBusPendingCallWatcher();
    initialize_meta_info_QDBusPendingReplyBase();
    initialize_meta_info_QDBusServer();
    initialize_meta_info_QDBusServiceWatcher();
    initialize_meta_info_QDBusSignature();
    initialize_meta_info_QDBusUnixFileDescriptor();
    initialize_meta_info_QDBusVariant();
    initialize_meta_info_QDBusVirtualObject();
    return QTJAMBI_ONLOAD_RETURN;
}

extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_dbus_QtJambi_1LibraryUtilities_internalAccess)(JNIEnv *env, jclass cls){
    jobject result{0};
    QTJAMBI_TRY{
        result = MetaInfoAPI::internalAccess(env, cls);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(env);
    }QTJAMBI_TRY_END
    return result;
}
